<?php

/**
 * Get Free Shipping PrestaShop module.
 *
 * @package   gmgetfreeshipping
 * @author    Dariusz Tryba (contact@greenmousestudio.com)
 * @copyright Copyright (c) Green Mouse Studio (http://www.greenmousestudio.com)
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */
if (!defined('_PS_VERSION_'))
    exit;

class GMGetFreeShipping extends Module {

    public function __construct() {
        $this->name = 'gmgetfreeshipping';
        $this->tab = 'front_office_features';
        $this->version = '1.2.0';
        $this->author = 'GreenMouseStudio.com';
        $this->need_instance = 0;
        $this->bootstrap = true;
        $this->ps_versions_compliancy = array('min' => '1.5', 'max' => '1.6.99.99');

        parent::__construct();

        $this->displayName = $this->l('Get free shipping');
        $this->description = $this->l('Display Spend another X to get free shipping message in cart');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    public function getContent() {
        $output = '';
        if (Tools::isSubmit('submitGmGetFreeShipping')) {
            $free_shipping = (int) Tools::getValue('GM_FREE_SHIPPING');
            Configuration::updateValue('GM_FREE_SHIPPING', $free_shipping);
            $output .= $this->displayConfirmation($this->l('Settings updated'));
        }
        return $output . $this->renderForm().$this->context->smarty->fetch($this->local_path . 'views/templates/admin/gms.tpl');
    }

    public function renderForm() {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs'
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('Free shipping starts at'),
                        'name' => 'GM_FREE_SHIPPING',
                        'class' => 'fixed-width-md',
                        'desc' => $this->l('Set to 0 to use global setting, currently set to: ') . Configuration::get('PS_SHIPPING_FREE_PRICE'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $lang = new Language((int) Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $this->fields_form = array();
        $helper->id = (int) Tools::getValue('id_carrier');
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitGmGetFreeShipping';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues() {
        return array(
            'GM_FREE_SHIPPING' => Tools::getValue('GM_FREE_SHIPPING', Configuration::get('GM_FREE_SHIPPING')),
        );
    }

    public function install() {
        if (Shop::isFeatureActive())
            Shop::setContext(Shop::CONTEXT_ALL);

        if (!parent::install() ||
                !$this->registerHook('shoppingCart')
        ) {
            return false;
        }
        Configuration::updateValue('GM_FREE_SHIPPING', 0);
        return true;
    }

    public function uninstall() {
        if (!Configuration::deleteByName('GM_FREE_SHIPPING') || !parent::uninstall())
            return false;
        return true;
    }

    public function hookShoppingCart($params) {
        $free_shipping = (int) Configuration::get('GM_FREE_SHIPPING');
        if (!$free_shipping) {
            $free_shipping = Configuration::get('PS_SHIPPING_FREE_PRICE');
        }
        if ($free_shipping) {
            $free_shipping_price = Tools::convertPrice($free_shipping);
            $cart = $this->context->cart;
            $total_without_shipping = $cart->getOrderTotal(true, Cart::BOTH_WITHOUT_SHIPPING);
            $remaining_to_spend = $free_shipping_price - $total_without_shipping;
            $this->context->smarty->assign(
                    array(
                        'free_shipping_price' => $free_shipping_price,
                        'total_without_shipping' => $total_without_shipping,
                        'remaining_to_spend' => $remaining_to_spend
                    )
            );
            return $this->display(__FILE__, 'gmgetfreeshipping.tpl');
        }
        return false;
    }

}
